@@ -1,71 +1,17 @@
 package BibTeX::Parser;
-our $VERSION = '0.4';
+BEGIN {
+  $BibTeX::Parser::VERSION = '0.5';
+}
 # ABSTRACT: A pure perl BibTeX parser
 use warnings;
 use strict;
 
 use BibTeX::Parser::Entry;
 
-=for stopwords jr von
-
-=head1 NAME
-
-BibTeX::Parser - A pure perl BibTeX parser
-
-=head1 VERSION
-
-version 0.4
-
-=cut
 
 my $re_namechar = qr/[a-zA-Z0-9\!\$\&\*\+\-\.\/\:\;\<\>\?\[\]\^\_\`\|]/o;
 my $re_name     = qr/$re_namechar+/o;
 
-=head1 SYNOPSIS
-
-Parses BibTeX files.
-
-    use BibTeX::Parser;
-	use IO::File;
-
-    my $fh     = IO::File->new("filename");
-
-    # Create parser object ...
-    my $parser = BibTeX::Parser->new($fh);
-    
-    # ... and iterate over entries
-    while (my $entry = $parser->next ) {
-	    if ($entry->parse_ok) {
-		    my $type    = $entry->type;
-		    my $title   = $entry->field("title");
-
-		    my @authors = $entry->author;
-		    # or:
-		    my @editors = $entry->editor;
-		    
-		    foreach my $author (@authors) {
-			    print $author->first . " "
-			    	. $author->von . " "
-				. $author->last . ", "
-				. $author->jr;
-		    }
-	    } else {
-		    warn "Error parsing file: " . $entry->error;
-	    }
-    }
-
-
-=head1 FUNCTIONS
-
-=head2 new
-
-Creates new parser object. 
-
-Parameters:
-
-	* fh: A filehandle
-
-=cut
 
 sub new {
     my ( $class, $fh ) = @_;
@@ -188,11 +134,6 @@ sub _parse_next {
     }
 }
 
-=head2 next
-
-Returns the next parsed entry or undef.
-
-=cut
 
 sub next {
     my $self = shift;
@@ -267,4 +208,85 @@ sub _extract_bracketed
 	}
 }
 
-1;    # End of BibTeX::Parser
\ No newline at end of file
+1;    # End of BibTeX::Parser
+__END__
+=pod
+
+=head1 NAME
+
+BibTeX::Parser - A pure perl BibTeX parser
+
+=head1 VERSION
+
+version 0.5
+
+=head1 SYNOPSIS
+
+Parses BibTeX files.
+
+    use BibTeX::Parser;
+	use IO::File;
+
+    my $fh     = IO::File->new("filename");
+
+    # Create parser object ...
+    my $parser = BibTeX::Parser->new($fh);
+    
+    # ... and iterate over entries
+    while (my $entry = $parser->next ) {
+	    if ($entry->parse_ok) {
+		    my $type    = $entry->type;
+		    my $title   = $entry->field("title");
+
+		    my @authors = $entry->author;
+		    # or:
+		    my @editors = $entry->editor;
+		    
+		    foreach my $author (@authors) {
+			    print $author->first . " "
+			    	. $author->von . " "
+				. $author->last . ", "
+				. $author->jr;
+		    }
+	    } else {
+		    warn "Error parsing file: " . $entry->error;
+	    }
+    }
+
+=for stopwords jr von
+
+=head1 NAME
+
+BibTeX::Parser - A pure perl BibTeX parser
+
+=head1 VERSION
+
+version 0.5
+
+=head1 FUNCTIONS
+
+=head2 new
+
+Creates new parser object. 
+
+Parameters:
+
+	* fh: A filehandle
+
+=head2 next
+
+Returns the next parsed entry or undef.
+
+=head1 AUTHOR
+
+Gerhard Gossen <gerhard.gossen@googlemail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Gerhard Gossen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
